from setuptools import setup, find_packages

setup(
    name='ErioonDB',
    version='0.1.2.7',
    description='ErioonDB Engine',
    author='Erioon',
    author_email='hello@erioon.com',
    packages=find_packages(),  
    install_requires=[],  
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License', 
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',  
)
